| Title: | Convert iGraph graps to SoNIA .son files |
|---|---|
| Description: | This program facilitates exporting igraph graphs to the SoNIA file format |
| Authors: | Sean J Westwood <[email protected]> |
| Maintainer: | Sean J Westwood <[email protected]> |
| License: | GPL (>= 2) |
| Version: | 1.0 |
| Built: | 2026-05-08 09:20:04 UTC |
| Source: | https://github.com/cran/igraphtosonia |
attachEdgeAtt Attach valid Edge attributes to the SoNIA output graph.
attachEdgeAtt(export_graph,source_graph,exportAttName,sourceAttName)attachEdgeAtt(export_graph,source_graph,exportAttName,sourceAttName)
export_graph |
graph formatted for SoNIA |
source_graph |
source (original) igraph graph |
exportAttName |
attribute name supported by SoNIA |
sourceAttName |
attribute name supported by igraph |
export_graph |
graph formatted for SoNIA with the specified attribute |
Sean J. Westwood [email protected]
####
attachVertexAtt Attach valid vertex attributes to the SoNIA output graph.
attachVertexAtt(export_graph,source_graph,exportAttName,sourceAttName)attachVertexAtt(export_graph,source_graph,exportAttName,sourceAttName)
export_graph |
graph formatted for SoNIA |
source_graph |
source (original) igraph graph |
exportAttName |
attribute name supported by SoNIA |
sourceAttName |
attribute name supported by igraph |
export_graph |
graph formatted for SoNIA with the specified attribute |
Sean J. Westwood [email protected]
####
write.graph.to.sonia Takes an igraph graph object and outputs a SoNIA import file
write.graph.to.sonia(source_graph,fileN)write.graph.to.sonia(source_graph,fileN)
source_graph |
graph to export |
fileN |
file name for export |
Sean J Westwood [email protected]
#example ## Not run: write.graph.to.sonia(graph,"export.son") ## End(Not run)#example ## Not run: write.graph.to.sonia(graph,"export.son") ## End(Not run)